@@ -4,6 +4,12 @@ from .Scaler import Scaler
 from .disassemble import disassemble
 
 
+_PCA_STATE = [
+	'_columns', '_scale', '_assembler', '_k', '_scaler', '_scale_with_means', '_scale_with_sd', '_fitted',
+	'_pca_columns'
+]
+
+
 class PCA:
 	def __init__(self, k=None, columns=None, scale=False, scale_with_means=True, scale_with_sd=True):
 		"""
@@ -23,10 +29,20 @@ class PCA:
 		self._scale_with_means = scale_with_means
 		self._scale_with_sd = scale_with_sd
 
+		self._pca = None
 		self._fitted = False
-
 		self._pca_columns = None
 
+	def __getstate__(self):
+		return {
+			name: getattr(self, name)
+			for name in _PCA_STATE
+		}
+
+	def __setstate__(self, state):
+		for name, value in state.items():
+			setattr(self, name, value)
+
 	def fit(self, X):
 		"""
 		:type X: DataFrame
@@ -52,8 +68,7 @@ class PCA:
 		"""
 		:type X: DataFrame
 		:type return_vector: bool
-		:param return_vector: if True, the vector column will be returned
-                            if False, the vector column will be disassembled
+		:param return_vector: True: the vector column will be returned. False: the vector column will be disassembled.
 		:rtype: DataFrame
 		"""
 		if not self._fitted:
