@@ -3,6 +3,10 @@ from pyspark.ml.feature import VectorAssembler, StandardScaler
 from .disassemble import disassemble
 
 
+_SCALER_STATE = [
+    '_columns', '_assembler', '_with_mean', '_with_sd', '_scaler', '_fitted'
+]
+
 class Scaler:
     def __init__(self, columns=None, with_mean=True, with_sd=True):
         """
@@ -17,6 +21,15 @@ class Scaler:
         self._scaler = None
         self._fitted = False
 
+    def __getstate__(self):
+        return {
+            name: getattr(self, name) for name in _SCALER_STATE
+        }
+
+    def __setstate__(self, state):
+        for name, value in state.items():
+            setattr(self, name, value)
+
     def fit(self, X):
         """
         :type X: DataFrame
